Tuples Mixed-Up Code Questions
------------------------------

.. selectquestion:: Tups_MixedUpCode_1_sq
   :fromid: tup_mixedupcode_1, tup_mixedupcode_1_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_2_sq
   :fromid: tup_mixedupcode_2, tup_mixedupcode_2_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_3_sq
   :fromid: tup_mixedupcode_3, tup_mixedupcode_3_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_4_sq
   :fromid: tup_mixedupcode_4, tup_mixedupcode_4_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_5_sq
   :fromid: tup_mixedupcode_5, tup_mixedupcode_5_ac
   :toggle: 

.. selectquestion:: Tups_MixedUpCode_6_sq
   :fromid: tup_mixedupcode_6, tup_mixedupcode_6_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_7_sq
   :fromid: tup_mixedupcode_7, tup_mixedupcode_7_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_8_sq
   :fromid: tup_mixedupcode_8, tup_mixedupcode_8_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_9_sq
   :fromid: tup_mixedupcode_9, tup_mixedupcode_9_ac
   :toggle: 


.. selectquestion:: Tups_MixedUpCode_10_sq
   :fromid: tup_mixedupcode_10, tup_mixedupcode_10_ac
   :toggle: 